package tech.powerjob.work.service.impl;

import cn.hutool.http.HttpResponse;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import tech.powerjob.work.entity.ShipIllegalArtificial;
import tech.powerjob.work.entity.ShipIllegalAuto;
import tech.powerjob.work.mapper.ShipIllegalAutoMapper;
import tech.powerjob.work.service.ShipIllegalArtificialService;
import tech.powerjob.work.service.ShipIllegalAutoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import tech.powerjob.work.util.DateUtils;
import tech.powerjob.work.util.ReturnMsg;
import tech.powerjob.worker.core.processor.ProcessResult;

import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
 *
 */
@Service
@Transactional
@Slf4j
public class ShipIllegalAutoServiceImpl extends ServiceImpl<ShipIllegalAutoMapper, ShipIllegalAuto> implements ShipIllegalAutoService {
    @Value("${illegalInfoUrl}")
    private String illegalInfoUrl;
    @Value("${infoSecretId}")
    private String infoSecretId;
    @Value("${infoSecretKey}")
    private String infoSecretKey;
    @Autowired
    private ShipIllegalArtificialService shipIllegalArtificialService;

    @Override
    public ProcessResult saveShipIllegalInfo() {
        try {
            Date date = new Date();
            String end = DateUtils.dateToString(date, "yyyy-MM-dd HH:mm");
            String start = DateUtils.dateToString(new Date(date.getTime() - 5 * 60 * 1000), "yyyy-MM-dd HH:mm");
            HttpResponse execute = HttpUtil.createGet(illegalInfoUrl + "start=" + start + "&end=" + end).
                    header("secretId", infoSecretId).
                    header("secretKey", infoSecretKey).execute();
            execute.close();
            HashMap hashMap = JSONObject.parseObject(execute.body(), HashMap.class);
            if (new Integer(0).equals(hashMap.get("code"))) {
                HashMap hashMap1 = JSONObject.parseObject(hashMap.get("data").toString(), HashMap.class);
                List<ShipIllegalAuto> auto = JSONObject.parseArray(hashMap1.get("auto").toString(), ShipIllegalAuto.class);
                List<ShipIllegalArtificial> artificial = JSONObject.parseArray(hashMap1.get("handle").toString(), ShipIllegalArtificial.class);
                if (!auto.isEmpty()) {
                    auto.forEach(i->i.setIndext(i.getIndex()));
                    this.saveOrUpdateBatch(auto);
                }
                if (!artificial.isEmpty()) {
                    artificial.forEach(i->i.setIndext(i.getIndex()));
                    shipIllegalArtificialService.saveOrUpdateBatch(artificial);
                }
            }
            return ReturnMsg.returnMsg(true);
        } catch (Exception e) {
            log.error("访问接口{}出现问题{}",illegalInfoUrl,e.getMessage());
            return ReturnMsg.returnMsg(false);
        }
    }
}




